# The pywwt Jupyter Widget Frontend Module

This NPM package contains the JavaScript code implementing the frontend of the
[pywwt] [Jupyter Widget]. As such, this package is mostly a pywwt implementation
detail.

[pywwt]: https://pywwt.readthedocs.io/
[Jupyter Widget]: https://ipywidgets.readthedocs.io/

To use the [AAS][aas] [WorldWide Telescope][wwt] (WWT) technology inside the
[JupyterLab] computational environment (NB: JupyterLab is distinct from
“vanilla” Jupyter), we recommend that you skip this widget and instead use the
[wwt-jupyterlab] extension. The dedicated extension installs the more powerful
WWT “[research app]” into your JupyterLab environment. That being said, this
package also includes a small JupyterLab extension that makes the pywwt widget
available within the JupyterLab context, if that’s what you want to use.

[aas]: https://aas.org/
[wwt]: https://worldwidetelescope.org/home
[JupyterLab]: https://jupyterlab.readthedocs.io/
[wwt-jupyterlab]: https://github.com/WorldWideTelescope/wwt-jupyterlab/
[research app]: https://docs.worldwidetelescope.org/research-app/latest/

To write your own WWT-based web apps, check out [documentation for the WWT web
stack][web-docs].

[web-docs]: https://docs.worldwidetelescope.org/webgl-reference/latest/

WWT is a free, open-source tool for visually exploring humanity’s scientific
understanding of the Universe. WWT is brought to you by the non-profit [American
Astronomical Society][aas] (AAS), the major organization of professional
astronomers in North America, and the [.NET Foundation][dnf].

[pywwt]: https://pywwt.readthedocs.io/
[dnf]: https://dotnetfoundation.org/

